@@ -1,8 +1,9 @@
 #ifndef ADDAPPLICATION_H
 #define ADDAPPLICATION_H
-#include "../include/AddApplicationBase.h"
 
-class AddApplication : public Form1
+#include "BAddApplication.h"
+
+class AddApplication : public BAddApplication
 { 
     Q_OBJECT
 
