@@ -5,6 +5,8 @@
 #define CMD_PING     0x0
 //! Function code for PONG messages.
 #define CMD_PONG     0x1
+//! Function code for BYE message.
+#define CMD_BYE      0x2
 //! Function code for QUERY messages.
 #define CMD_QUERY    0x80
 //! Function code for QUERY_HIT messages.
@@ -16,7 +18,7 @@
 
 #define IMAGES       "gif;bmp;jpg;jpeg;jpe;psp;xpm;tif;tiff;png;ps;eps;tga;xcf"
 #define VIDEOS       "asf;mpg;mpeg;mov;qt;avi"
-#define MUSIC        "wav;au;aif;aiff;ram;ra;mp3"
+#define MUSIC        "wav;au;aif;aiff;ram;ra;mp3;ogg;rm"
 
 #define CONNECT_STR  "GNUTELLA CONNECT/0.4\n\n"
 #define RESPONSE_STR "GNUTELLA OK\n\n"
