@@ -2,19 +2,21 @@
 #define PING_H
 
 #include <string>
-#include <stdint.h>
+#include <qglobal.h>
 
+#if !defined(_WIN32)
 using namespace std;
+#endif
 
 class Ping
 {
  public:
-  Ping(const uint8_t ttl, const uint8_t hops, std::string id);
+  Ping(const Q_UINT8 ttl, const Q_UINT8 hops, std::string id);
 
   std::string  _id;
   std::string  _data;
-  uint8_t      _ttl;
-  uint8_t      _hops;
+  Q_UINT8      _ttl;
+  Q_UINT8      _hops;
 };
 
 #endif
