@@ -2,31 +2,36 @@
 #define QUERYHITENTRY_H
 
 class QListViewItem;
+
 #include <string>
 #include "Address.h"
 
+#if !defined(_WIN32)
 using namespace std;
+#endif
 
 class QueryHitEntry
 {
  public:
   QueryHitEntry();
-  QueryHitEntry(std::string& filename, const uint32_t size, const uint32_t index, const uint32_t speed, int status, Address& addr, std::string& id, QListViewItem *item);
+  QueryHitEntry(std::string& filename, const Q_UINT32 size, const Q_UINT32 index, const Q_UINT32 speed, int status, Address& addr, std::string& id, QListViewItem *item);
   ~QueryHitEntry();
 
+  bool operator==(QueryHitEntry& q) { return( (filename==q.filename) && (size==q.size) && (index==q.index) ); };
+
   bool              firewalled();
   
   //! Filename of QueryHit.
   std::string       filename;
 
   //! Size of file.
-  uint32_t          size;
+  Q_UINT32          size;
 
   //! Index of file.
-  uint32_t          index;
+  Q_UINT32          index;
 
   //! Download speed of host.
-  uint32_t          speed;
+  Q_UINT32          speed;
 
   //! Address of host.
   Address           addr;
@@ -37,7 +42,7 @@ class QueryHitEntry
   //! Gnutella ID of host.
   std::string       id;
 
-  //! Pointer to item in QListView.
+  //! Pointer to item in QListView of search results.
   QListViewItem*    item;
 
   static const int  Busy;
