@@ -1,12 +1,15 @@
 #ifndef SEARCHWIDGET_H
 #define SEARCHWIDGET_H
-#include "../include/SearchWidgetBase.h"
+
+#include "BSearchWidget.h"
 
 class QtellaSub;
 
+#if !defined(_WIN32)
 using namespace std;
+#endif
 
-class SearchWidget : public SearchWidgetBase
+class SearchWidget : public BSearchWidget
 { 
     Q_OBJECT
 
