@@ -5,7 +5,9 @@
 
 class SharedViewItem;
 
+#if !defined(_WIN32)
 using namespace std;
+#endif
 
 class SharedFile
 {
@@ -15,6 +17,7 @@ class SharedFile
   ~SharedFile();
 
   std::string completeFilename();
+  bool        renameFile(std::string newname);
 
   bool operator==(SharedFile &f) { return (f.file==file) && (f.directory==directory); };
   
@@ -24,6 +27,9 @@ class SharedFile
   int                uploads;
   int                requests;
   SharedViewItem     *item;
+
+  //! This is a pointer to the SHA1 stored 
+  QString            *_sha1;
 };
 
 #endif
