@@ -4,7 +4,9 @@
 #include <string>
 #include <strstream>
 
+#if !defined(_WIN32)
 using namespace std;
+#endif
 
 class Statistic
 {
@@ -46,7 +48,13 @@ class Statistic
   unsigned long    hits_qtel_n;
   unsigned long    hits_lime_n;
   unsigned long    hits_bear_n;
+  unsigned long    hits_gtkg_n;
+  unsigned long    hits_gnot_n;
+  unsigned long    hits_snut_n;
+  unsigned long    hits_xolo_n;
   unsigned long    hits_othe_n;
+  unsigned long    hits_gnuc_n;
+  unsigned long    hits_mrph_n;
 
   double  loads_usucc;
   double  loads_uabor;
@@ -57,6 +65,10 @@ class Statistic
 
   double shared_files;
   double shared_size;
+
+  //! used for sh1 statistics
+  double _n_total_queries;
+  double _n_sha1_queries;
 };
 
 #endif
