@@ -13,22 +13,27 @@ class UploadManager;
 class QListViewItem;
 class QTimer;
 
+#if !defined(_WIN32)
 using namespace std;
+#endif
 
 class Upload : public QObject
 {
   Q_OBJECT
 
  public:
-  Upload(UploadManager *parent, std::string data, QSocket *socket);
+  Upload(UploadManager *parent, const std::string& data, QSocket *socket);
   Upload(UploadManager *parent, Push push);
 
   ~Upload();
 
-  void initUpload();
-  int  getState();
-  void setState(int state);
-  void abortUpload();
+  void                   initUpload();
+  int                    getState();
+  void                   setState(int state);
+  void                   abortUpload();
+  double                 readBandwidth();
+
+  const std::string&     getRemoteIP();
 
   enum {  
     Busy,
@@ -47,8 +52,10 @@ class Upload : public QObject
   QFile             _file;
   QTime             _time_start;
   Push              _push_data;
-
+  
  private:
+  std::string       _remote_ip;
+  double            _bandwidth;
   unsigned long     _written;
   unsigned long     _towrite;
   QSocket*          _socket;
@@ -65,6 +72,9 @@ class Upload : public QObject
 
   static const std::string statestr[];
 
+  private:
+  void send404();
+
  private slots:
   void              slotClosed();
   void              slotTimer();
